from codecs import open
from os import path

from setuptools import setup

here = path.abspath(path.dirname(__file__))
version = None
exec(open('netlab/version.py').read())

setup(
    name='netlab',
    version=version,

    description="NETLAB+ VE SDK for Python",
    url='https://www.netdevgroup.com/products/',

    author='Network Development Group',
    author_email='support@netdevgroup.com',

    license='MIT',

    # https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Education',
        'Intended Audience :: System Administrators',
        'Intended Audience :: Information Technology',
        'Topic :: Utilities',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3 :: Only',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Natural Language :: English',
        'Operating System :: MacOS :: MacOS X',
        'Operating System :: Microsoft :: Windows',
        'Operating System :: POSIX :: Linux',
    ],

    # What does your project relate to?
    keywords='netlab development netlab ndg',

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    packages=['netlab', 'netlab.api', 'netlab.cli', 'netlab.enums', 'netlab.errors'],

    install_requires=[
        'click >= 6.6',
        'tabulate >= 0.7'
    ],

    # List additional groups of dependencies here (e.g. development
    # dependencies). You can install these using the following syntax,
    # for example:
    # $ pip install -e .[dev]
    extras_require={
        'dev': [
            'pytest >= 3.0.1', 'tox >= 2.4', 'Sphinx >= 1.5.0', 'recommonmark >= 0.4.0',
            'sphinx-autobuild >= 0.6.0', 'sphinx-rtd-theme == 0.1.9'
        ]
    },

    entry_points={
        'console_scripts': [
            'netlab=netlab.cli:main',
        ],
    },
)
